# Assess Acceptability Judgments

A minimalist package to assess acceptability judgments using

- [SLOR](https://arxiv.org/pdf/1809.08731v1.pdf)
- [WPSLOR](https://arxiv.org/pdf/1809.08731v1.pdf)
- [Negative Cross-Entropy (NCE)](https://arxiv.org/pdf/1809.08731v1.pdf)
- [Perplexity](https://arxiv.org/pdf/1809.08731v1.pdf)

